/* ========================================
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 * ========================================
*/
/*******************************************************************************
* File Name: main.c
* 
* Description: This program takes analog input (0,0v to 3,3v) from pin P0.7 
*              and display converted result on LCD 
*
* ADC Configuration:
*             16-Bit ADC mit Del_Sig
*             conversion Mode: Single Sample
*             Input Range:     Vssa to Vdda (0,0v to 3,3v)
*             Input Mode:      Single Ended
* 
* Hardware Connections:
*    Connect analog input to port P0[7] of DVK1 board.
*
* PWM Configuration:
*             16-Bit UDB PWM
*             Period: 65535
*             Interrupt: None
*             Output Pin: P0.0 (PWM 2)
                          P0.1 (PWM 1)
* Clock Frequency 12 MHz
*
*

*/

#include <project.h>

/*******************************************************************************
* Function Name: Sys_Init
********************************************************************************
* Summary:
*  Sys_Init() performs following functions:
*  1: Initializes the LCD
*
* Parameters: None.
* Return: None.
*******************************************************************************/
void Sys_Init(void)
{
	LCD_Start();
	LCD_Position(0u,0u);
	LCD_PrintString("Initializing..");			
	CyDelay(1500); 	
	LCD_ClearDisplay(); 	
}
/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
*  main() performs following functions:
*  1: Starts ADC
*  2: Starts ADC converstion.
*  3: Gets the converted result and displays it in LCD.
*
* Parameters: None.
* Return: None.
*
*******************************************************************************/
uint16 ADC_Max=65535;
uint16 ADC_Min=0;

uint16 ADC_Result;
uint16 i=0;
float Comp_Val;

int main()
{       
    // Start the components 
	Sys_Init(); 
    ADC_DelSig_Start();			  	
		 
	//CyGlobalIntEnable;  // Uncomment this line to enable global interrupts.

    LCD_Position(0u, 0u);
    LCD_PrintString("ADC_Output");
	
	// Start Clock & PWM
	Clock_Start();
	PWM_Start();						

    while(1)
    {
		ADC_DelSig_StartConvert();  // Start the ADC conversion 
		
        if(ADC_DelSig_IsEndConversion(ADC_DelSig_RETURN_STATUS)) // Check ADC EOC flag
        {
            ADC_Result = ADC_DelSig_GetResult32(); // Get Result
													
            LCD_Position(1u, 0u);				
			LCD_PrintDecUint16(ADC_DelSig_CountsTo_mVolts(ADC_Result)); // Display ADC result in mVolts on LCD
			CyDelay(1000);	
									
			//Comp_Val = (float)(PWM_ReadPeriod() / (ADC_Max * ADC_Result));						 
			//PWM_WritePeriod(PWM_ReadPeriod() );
			//PWM_WriteCompare(Comp_Val); 									
			
			/* i want to do this as per my ADC Result */
			PWM_WritePeriod(65535);
			PWM_WriteCompare1(32768); 			
			
        }
    }
}

/* [] END OF FILE */
